netapp_ontap.resources.s3_user API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.s3_user`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

An S3 user account is created on the S3 server. Buckets that are created for the server are associated with that user (as the owner of the buckets). The creation of the user account involves generating a pair of keys "access" and "secret". These keys are shared with clients (by the administrator out of band) who want to access the S3 server. The access_key is sent in the request and it identifies the user performing the operation. The client or server never send the secret_key over the wire. Only the access_key can be retrieved from a GET operation. The secret_key along with the access_key is returned from a POST operation and from a PATCH operation if the administrator needs to regenerate the keys. If the user is part of active-directory, the user name takes the format "user@fully_qualified_domain_name".

## Examples

### Retrieving S3 user configurations for a particular SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(S3User.get_collection("db2ec036-8375-11e9-99e1-0050568e3ed9", fields="*"))
        )

Try it out

    [
        S3User(
            {
                "key_expiry_time": "2023-11-13T23:28:03+05:30",
                "access_key": "<AWS-ACCESS-KEY-ID>",
                "name": "user-1",
                "key_time_to_live": "PT3H5M",
                "comment": "S3 user",
                "svm": {
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/db2ec036-8375-11e9-99e1-0050568e3ed9"
                        }
                    },
                    "uuid": "db2ec036-8375-11e9-99e1-0050568e3ed9",
                },
            }
        ),
        S3User(
            {
                "access_key": "<AWS-ACCESS-KEY-ID>",
                "name": "user-2",
                "comment": "s3-user",
                "svm": {
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/db2ec036-8375-11e9-99e1-0050568e3ed9"
                        }
                    },
                    "uuid": "db2ec036-8375-11e9-99e1-0050568e3ed9",
                },
            }
        ),
    ]

### Retrieving the user configuration of a specific S3 user

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3User("db2ec036-8375-11e9-99e1-0050568e3ed9", name="user-1")
        resource.get()
        print(resource)

Try it out

    S3User(
        {
            "key_expiry_time": "2023-02-20T10:04:31+00:00",
            "access_key": "<AWS-ACCESS-KEY-ID>",
            "name": "user-1",
            "key_time_to_live": "P6DT1H5M",
            "comment": "s3-user",
            "svm": {
                "name": "vs1",
                "_links": {
                    "self": {"href": "/api/svm/svms/db2ec036-8375-11e9-99e1-0050568e3ed9"}
                },
                "uuid": "db2ec036-8375-11e9-99e1-0050568e3ed9",
            },
        }
    )

### Creating an S3 user configuration

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3User("db2ec036-8375-11e9-99e1-0050568e3ed9")
        resource.name = "user-1"
        resource.post(hydrate=True)
        print(resource)

Try it out

    S3User(
        {
            "access_key": "<AWS-ACCESS-KEY-ID>",
            "name": "user-1",
            "secret_key": "<AWS-SECRET-ACCESS-KEY>",
        }
    )

### Creating an S3 user configuration with key expiration configuration

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3User("db2ec036-8375-11e9-99e1-0050568e3ed9")
        resource.comment = "S3 user3"
        resource.key_time_to_live = "P6DT1H5M"
        resource.name = "user-3"
        resource.post(hydrate=True)
        print(resource)

Try it out

    S3User(
        {
            "key_expiry_time": "2023-06-16T12:08:38+00:00",
            "access_key": "<AWS-ACCESS-KEY-ID>",
            "name": "user-3",
            "secret_key": "<AWS-SECRET-ACCESS-KEY>",
        }
    )

### Creating an S3 user configuration with user keys specified

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3User("db2ec036-8375-11e9-99e1-0050568e3ed9")
        resource.access_key = "<AWS-ACCESS-KEY-ID>"
        resource.comment = "S3 user"
        resource.key_time_to_live = "PT6H3M"
        resource.name = "user-test"
        resource.secret_key = "<AWS-SECRET-ACCESS-KEY>"
        resource.post(hydrate=True)
        print(resource)

Try it out

    S3User(
        {
            "key_expiry_time": "2024-02-12T22:36:29+05:30",
            "access_key": "<AWS-ACCESS-KEY-ID>",
            "name": "user-test",
            "secret_key": "<AWS-SECRET-ACCESS-KEY>",
        }
    )

### Creating an S3 user configuration with a key expiration configuration and where the user is part of Active directory.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3User("db2ec036-8375-11e9-99e1-0050568e3ed9")
        resource.comment = "S3 user3"
        resource.key_time_to_live = "P6DT1H5M"
        resource.name = "user-3@domain1.com"
        resource.post(hydrate=True)
        print(resource)

Try it out

    S3User(
        {
            "key_expiry_time": "2023-06-16T12:08:38+00:00",
            "access_key": "<AWS-ACCESS-KEY-ID>",
            "name": "user-3@domain1.com",
            "secret_key": "<AWS-SECRET-ACCESS-KEY>",
        }
    )

### Regenerating first key for a specific S3 user for the specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3User("db2ec036-8375-11e9-99e1-0050568e3ed9", name="user-2")
        resource.patch(hydrate=True, regenerate_keys=True)

### Regenerating keys and setting new expiry configuration for a specific S3 user for the specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3User("db2ec036-8375-11e9-99e1-0050568e3ed9", name="user-2")
        resource.key_time_to_live = "PT6H3M"
        resource.patch(hydrate=True, regenerate_keys=True)

### Regenerating keys by specifying keys in the input

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3User("db2ec036-8375-11e9-99e1-0050568e3ed9", name="user-2")
        resource.access_key = "<AWS-ACCESS-KEY-ID>"
        resource.comment = "S3 user"
        resource.key_time_to_live = "PT6H3M"
        resource.secret_key = "<AWS-SECRET-ACCESS-KEY>"
        resource.patch(hydrate=True, regenerate_keys=True)

### Deleting first key for a specific S3 user for a specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3User("db2ec036-8375-11e9-99e1-0050568e3ed9", name="user-2")
        resource.patch(hydrate=True, delete_keys=True)

### Deleting the specified S3 user configuration for a specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3User

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3User("03ce5c36-f269-11e8-8852-0050568e5298", name="user-2")
        resource.delete()

## Classes

`class S3User (*args, **kwargs)`

  This is a container of S3 users.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all S3User resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('S3User')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes the S3 user configuration of an SVM.

    ### Related ONTAP commands

    - `vserver object-store-server user delete`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/users`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent S3User resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the S3 user's SVM configuration.

    ### Related ONTAP commands

    - `vserver object-store-server user show`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/users`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves the S3 user's SVM configuration.

    ### Related ONTAP commands

    - `vserver object-store-server user show`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/users`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('S3User')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the S3 user configuration of an SVM.

    ### Important notes

    - User access_key and secret_key pair can be regenerated using the PATCH operation.
    - User access_key and secret_key is returned in a PATCH operation if the "regenerate_keys" field is specified as true.
    - If "regenerate_keys" is true and user keys have expiry configuration, then "key_expiry_time" is also returned as part of response.
    - User access_key and secret_key pair can be deleted using the PATCH operation.

    ### Recommended optional properties

    - `regenerate_keys` - Specifies if secret_key and access_key need to be regenerated.
    - `delete_keys` - Specifies if secret_key and access_key need to be deleted.
    - `comment` - Any information related to the S3 user.

    ### Related ONTAP commands

    - `vserver object-store-server user show`
    - `vserver object-store-server user regenerate-keys`
    - `vserver object-store-server user delete-keys`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/users`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('S3User')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[S3User], NetAppResponse]`

    Creates the S3 user configuration.

    ### Important notes

    - Each SVM can have one or more user configurations.
    - If the user is a member of Active directory, the user name takes the format "user@FQDN". For example, "user1@domain1.com".
    - If user creation is successful, a user access_key and secret_key is returned as part of the response.
    - If user keys have expiry configuration, then "key_expiry_time" is also returned as part of the response.
    - User access and secret keys can be specified in the input. If not specified, keys are generated automatically.

    ### Required properties

    - `svm.uuid` - Existing SVM in which to create the user configuration.
    - `name` - User name that is to be created.

    ### Default property values

    - `comment` - ""

    ### Related ONTAP commands

    - `vserver object-store-server user create`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/users`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes the S3 user configuration of an SVM.

    ### Related ONTAP commands

    - `vserver object-store-server user delete`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/users`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the S3 user configuration of an SVM.

    ### Related ONTAP commands

    - `vserver object-store-server user show`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/users`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates the S3 user configuration of an SVM.

    ### Important notes

    - User access_key and secret_key pair can be regenerated using the PATCH operation.
    - User access_key and secret_key is returned in a PATCH operation if the "regenerate_keys" field is specified as true.
    - If "regenerate_keys" is true and user keys have expiry configuration, then "key_expiry_time" is also returned as part of response.
    - User access_key and secret_key pair can be deleted using the PATCH operation.

    ### Recommended optional properties

    - `regenerate_keys` - Specifies if secret_key and access_key need to be regenerated.
    - `delete_keys` - Specifies if secret_key and access_key need to be deleted.
    - `comment` - Any information related to the S3 user.

    ### Related ONTAP commands

    - `vserver object-store-server user show`
    - `vserver object-store-server user regenerate-keys`
    - `vserver object-store-server user delete-keys`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/users`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates the S3 user configuration.

    ### Important notes

    - Each SVM can have one or more user configurations.
    - If the user is a member of Active directory, the user name takes the format "user@FQDN". For example, "user1@domain1.com".
    - If user creation is successful, a user access_key and secret_key is returned as part of the response.
    - If user keys have expiry configuration, then "key_expiry_time" is also returned as part of the response.
    - User access and secret keys can be specified in the input. If not specified, keys are generated automatically.

    ### Required properties

    - `svm.uuid` - Existing SVM in which to create the user configuration.
    - `name` - User name that is to be created.

    ### Default property values

    - `comment` - ""

    ### Related ONTAP commands

    - `vserver object-store-server user create`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/users`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class S3UserSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the S3User object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access_key: str GET POST PATCH`

    Specifies the access key for the user.

    Example:

  `comment: str GET POST PATCH`

    Can contain any additional information about the user being created or modified.

    Example: S3 user

  `key_expiry_time: ImpreciseDateTime GET`

    Specifies the date and time after which keys expire and are no longer valid.

    Example: 2024-01-01T00:00:00.000+0000

  `key_time_to_live: str GET POST PATCH`

    Indicates the time period from when this parameter is specified:

    - when creating or modifying a user or
    - when the user keys were last regenerated, after which the user keys expire and are no longer valid.
    - Valid format is: 'PnDTnHnMnS|PnW'. For example, P2DT6H3M10S specifies a time period of 2 days, 6 hours, 3 minutes, and 10 seconds.
    - If the value specified is '0' seconds, then the keys won't expire.

    Example: PT6H3M

  `name: str GET POST`

    Specifies the name of the user. A user name length can range from 1 to 64 characters and can only contain the following combination of characters 0-9, A-Z, a-z, "_", "+", "=", ",", ".","@", and "-".

    Example: user-1

  `secret_key: str POST PATCH`

    Specifies the secret key for the user.

    Example:

  `svm: Svm GET`

    The svm field of the s3_user.